"""
:mod:`tests.conftest` module.

Test-wide shared pytest fixtures for the test suite.
tests-wide conftest.

This file intentionally left minimal. Shared fixtures have been scoped to
the appropriate subtrees (unit or integration) to avoid cross-contamination.
"""

from __future__ import annotations
